@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-'''Turbo tunnel
-'''
+"""Turbo tunnel
+"""
 
-VERSION = '0.4.2'
+VERSION = "0.5.0"
 
 import sys
 import traceback
@@ -12,6 +12,7 @@ try:
     from . import https
     from . import server
     from . import socks
+
     if sys.version_info[1] >= 6:
         # ssh disabled in python 3.5
         from . import ssh
